@@ -1,8 +1,5 @@
 #!/usr/bin/python3
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2019-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 """Grep Python tracebacks in logfiles"""
@@ -406,6 +403,11 @@ COMMON_EXCEPTIONS = (
     E("KeyError: 'triggererror'", ['csv_reader.py']),
     E(r"ucsschool.importer.reader.csv_reader.UnsupportedEncodingError: Unsupported encoding 'binary' detected, please check the manual for supported encodings.", ['csv_reader.py'], 56846),  # ucs-test-ucsschool/90_ucsschool/252_import_works_with_encodings and 252a_csv_reader_correct_encodings expect this traceback
 
+    # errors during keycloak reconfiguration
+    E(r'OSError: \[Errno 113\] No route to host', ['urllib']),
+    E(r'urllib3.exceptions.NewConnectionError:.*\[Errno 113\] No route to host', ['urllib']),
+    E('urllib3.exceptions.MaxRetryError:.*Max retries exceeded.* /univention/saml/metadata.*', ['urllib']),
+    E('requests.exceptions.ConnectionError:.*Max retries exceeded.* /univention/saml/metadata.*', ['requests']),
     # E(r'.*', ['File "/usr/share/ucs-test/']),
 )
 
